use strict;
use utf8;
use warnings;

package noris::Ticket::API::RT::Connection;

use Moose;
use noris::Ticket::API::RT::SelectResult;

sub change_user {
    # my ($self, $user_name) = @_;
    # change_user() macht in RT gar nichts.
}

sub select_tickets {
    my ($self, %param) = @_;
    return noris::Ticket::API::RT::SelectResult->new(
        connection => $self, 
        attributes => $param{attributes} || [], 
        query => $param{query},
    );
}

sub is_open {
	1;
}

1;
